@@ -1,26 +1,47 @@
+from __future__ import annotations
+
 import os
-import time
+import typing
 from abc import abstractmethod
+from time import sleep
 from typing import Optional, List
 
-from pollect.core import OSEnv, Helper
+from pollect.core import OSEnv
+from pollect.core.Log import Log
 from pollect.core.ValueSet import ValueSet, Value
-from pollect.sources import Log
+
+if typing.TYPE_CHECKING:
+    from pollect.core.Core import Configuration
 
 
-class Source:
+class Source(Log):
+    """
+    A single metrics source. May return multiple metrics and labels
+    """
+
     type: str = None
+    """
+    Type string of this source
+    """
+
     name: Optional[str] = None
+    """
+    Name of this source, may be used as value name prefix
+    """
+
+    labels: typing.Dict[str, str] = {}
+    """
+    Static labels which should be added to all values
+    """
+
+    global_conf: Configuration
 
     def __init__(self, config):
+        super().__init__(config['type'])
         self.name = config.get('name')
-        self.type = config['type']
-        self.global_conf = None
-        """
-        Global configuration
 
-        :type global_conf: Configuration
-        """
+        self.labels = config.get('labels', {})
+        self.type = config['type']
 
     def setup(self, global_conf):
         """
@@ -44,8 +65,20 @@ class Source:
             results = [results]
         for result in results:
             result.name = self._get_suffix()
+
+            # Add static labels from config
+            result.labels.extend(self.labels.keys())
+            for value in result.values:
+                value.label_values.extend(self.labels.values())
+
         return results
 
+    def shutdown(self):
+        """
+        Terminates any background jobs running for this source
+        """
+        pass
+
     @abstractmethod
     def _probe(self) -> Optional[ValueSet] or List[ValueSet]:
         """
@@ -65,23 +98,21 @@ class Source:
             return self.type
         return self.type + '.' + self.name
 
+    def __str__(self):
+        return self._get_suffix()
 
-class HttpSource(Source):
+
+class DummySource(Source):
     def __init__(self, config):
         super().__init__(config)
-        self.url = config.get('url')
-        self.timeout = config.get('timeout', 10)
+        self.value = config.get('value')
+        self.sleep = config.get('sleep', 0)
 
-    def _probe(self):
+    def _probe(self) -> Optional[ValueSet]:
+        if self.sleep > 0:
+            sleep(self.sleep)
         data = ValueSet()
-        try:
-            start = time.time() * 1000
-            Helper.get_url(self.url, timeout=self.timeout)
-            end = time.time() * 1000
-            data.add(Value(int(end - start)))
-        except Exception as e:
-            Log.error('Could not probe ' + str(e))
-            data.add(Value(self.timeout))
+        data.add(Value(self.value))
         return data
 
 
